@@ -3,19 +3,19 @@ library(EnsDb.Hsapiens.v75)
 edb <- EnsDb.Hsapiens.v75
 
 test_crunch_ensdb <- function(){
-    zbtb <- genes(edb, filter=GenenameFilter("ZBTB16"))
+    zbtb <- genes(edb, filter = ~ genename == "ZBTB16")
 
     Zens <- crunch(edb, zbtb)
+    checkTrue(all(Zens$gene_name == "ZBTB16"))
+    ## Expect a single gene.
+    checkEquals(length(unique(Zens$gene_id)), 1)
     ## crunch without which but using a filter.
-    Test <- crunch(edb, GenenameFilter("ZBTB16"))
+    Test <- crunch(edb, ~ genename == "ZBTB16")
+    checkEquals(Zens, Test)
 
     ## Testing exceptions:
-    checkException(crunch(edb, which="bla"))
-    checkException(crunch(edb, which=list(GenenameFilter("ZBTB16"), "bla")))
+    checkException(crunch(edb, which = "bla"))
 
-    Test <- crunch(edb, zbtb)
-    ## Expect a single gene.
-    checkEquals(length(unique(Test$gene_id)), 1)
     strand(zbtb) <- "*"
     ## Expect two genes.
     Test <- crunch(edb, zbtb)
@@ -23,12 +23,12 @@ test_crunch_ensdb <- function(){
 
     ## Testing columns
     wantCols <- c("gene_biotype", "tx_biotype")
-    Test <- crunch(edb, zbtb, columns=wantCols)
+    Test <- crunch(edb, zbtb, columns = wantCols)
     checkTrue(all(wantCols %in% colnames(mcols(Test))))
 
     ## Now let's try a tricky one...
-    Test <- crunch(edb, which=GenenameFilter("ALDOA"))
-    gr <- GRanges(seqnames=16, IRanges(30768000, 30770000), strand="*")
-    Test <- crunch(edb, which=gr)
+    Test <- crunch(edb, which = GenenameFilter("ALDOA"))
+    gr <- GRanges(seqnames = 16, IRanges(30768000, 30770000), strand = "*")
+    Test <- crunch(edb, which = gr)
 }
 
